% Demo file for eigBSE algorithm
% Author: Zhilin Zhang
% E-mail: zhang@sccn.ucsd.edu
% Date: July 2005

clear;clc;close all;

t = 0:0.001:2;
N = length(t);

% generate three source signals with the same period length 20, but having different
% autocorreltion values at lag 20
S(1,:) = sin(2*pi*50*t);
S(2,:) = sin(2*pi*50*t + pi/2) + 0.3 * randn(1,N);
v = [1 : N];  S(3,:) = ((rem(v,20)-10)/9).^5 + 0.6 * randn(1,N);
S = standarize(S);        % zero mean and unit variance
ICAshow(S(:,1:100),'title','Source Signals');        % plot the sources

showAC(S,99,'title','Autocorrelation of Sources');  % plot the autocorrelation of each source


A = rand(3);          % mixing matrix
X = A * S;            % mixed signals
[Z,H] = whiten(X);    % whitening

tmdelay = [1:4]*20;    % select suitable lags
selectionIC = [1,3];   % extract the signals corresponding to the 1-th,3-th largest eigenvalue

[y_eigBSE,w_eigBSE] = eigBSE(Z, tmdelay, selectionIC);   % run the algorithm
y_eigBSE = standarize(y_eigBSE);     
icashow(y_eigBSE(:,1:100),'title','Separated Signals by eigBSE');  % plot the separated sources





